==> jc-1.4.0.tar.gz: javax/swing/text/StyleConstants__24FontConstants.h <==
// public class javax.swing.text.StyleConstants$FontConstants

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 33098ca6f888e073 javax_swing_text_StyleConstants
// @dep_class 1bb8530cf2456834 javax_swing_text_StyleConstants__24FontConstants

// header file dependencies
// @dep_header javax_swing_text_StyleConstants

#include "javax/swing/text/StyleConstants.h"

#ifndef _JC_javax_swing_text_StyleConstants__24FontConstants_H_
#define _JC_javax_swing_text_StyleConstants__24FontConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyleConstants__24FontConstants$sub_refs	_jc_javax_swing_text_StyleConstants__24FontConstants$sub_refs;
typedef struct _jc_javax_swing_text_StyleConstants__24FontConstants$sub_nonrefs	_jc_javax_swing_text_StyleConstants__24FontConstants$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyleConstants__24FontConstants$refs	_jc_javax_swing_text_StyleConstants__24FontConstants$refs;
typedef struct _jc_javax_swing_text_StyleConstants__24FontConstants$nonrefs	_jc_javax_swing_text_StyleConstants__24FontConstants$nonrefs;
typedef struct _jc_javax_swing_text_StyleConstants__24FontConstants$object	_jc_javax_swing_text_StyleConstants__24FontConstants$object;

typedef struct _jc_javax_swing_text_StyleConstants__24FontConstants$fields_struct	_jc_javax_swing_text_StyleConstants__24FontConstants$fields_struct;
typedef const struct _jc_javax_swing_text_StyleConstants__24FontConstants$vmethods	_jc_javax_swing_text_StyleConstants__24FontConstants$vmethods;
typedef const struct _jc_javax_swing_text_StyleConstants__24FontConstants$vtable	_jc_javax_swing_text_StyleConstants__24FontConstants$vtable;
typedef const struct _jc_javax_swing_text_StyleConstants__24FontConstants$vtype	_jc_javax_swing_text_StyleConstants__24FontConstants$vtype;

// Class fields structure
struct _jc_javax_swing_text_StyleConstants__24FontConstants$fields_struct {
	struct _jc_java_lang_Object$object	*Bold;
	struct _jc_java_lang_Object$object	*Family;
	struct _jc_java_lang_Object$object	*Italic;
	struct _jc_java_lang_Object$object	*Size;
};
extern _jc_javax_swing_text_StyleConstants__24FontConstants$fields_struct _jc_javax_swing_text_StyleConstants__24FontConstants$class_fields;

// Constructors
extern void _jc_javax_swing_text_StyleConstants__24FontConstants$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_text_StyleConstants__24FontConstants$object *, struct _jc_java_lang_String$object *);

// Static methods
extern void _jc_javax_swing_text_StyleConstants__24FontConstants$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_javax_swing_text_StyleConstants__24FontConstants$vmethods {
};

// Vtable
struct _jc_javax_swing_text_StyleConstants__24FontConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_StyleConstants$vmethods	javax_swing_text_StyleConstants;
	_jc_javax_swing_text_StyleConstants__24FontConstants$vmethods	javax_swing_text_StyleConstants__24FontConstants;
};

// Vtype
struct _jc_javax_swing_text_StyleConstants__24FontConstants$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyleConstants__24FontConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyleConstants__24FontConstants$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyleConstants__24FontConstants$refs {
    _jc_javax_swing_text_StyleConstants__24FontConstants$sub_refs	javax_swing_text_StyleConstants__24FontConstants;
    _jc_javax_swing_text_StyleConstants$sub_refs	javax_swing_text_StyleConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyleConstants__24FontConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyleConstants__24FontConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_StyleConstants$sub_nonrefs	javax_swing_text_StyleConstants;
    _jc_javax_swing_text_StyleConstants__24FontConstants$sub_nonrefs	javax_swing_text_StyleConstants__24FontConstants;
};

// Object instance structure
struct _jc_javax_swing_text_StyleConstants__24FontConstants$object {
	_jc_javax_swing_text_StyleConstants__24FontConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyleConstants__24FontConstants$vtype	*vtype;
	_jc_javax_swing_text_StyleConstants__24FontConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyleConstants__24FontConstants$vtype _jc_javax_swing_text_StyleConstants__24FontConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyleConstants__24FontConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyleConstants__24FontConstants$class_object;

#endif	/* _JC_javax_swing_text_StyleConstants__24FontConstants_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/StyleConstants__24FontConstants.h <==
// public class javax.swing.text.StyleConstants$FontConstants

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 602dc460083efcf4 javax_swing_text_StyleConstants
// @dep_class 495fd3b2c78e2000 javax_swing_text_StyleConstants__24FontConstants

// header file dependencies
// @dep_header javax_swing_text_StyleConstants

#include "javax/swing/text/StyleConstants.h"

#ifndef _JC_javax_swing_text_StyleConstants__24FontConstants_H_
#define _JC_javax_swing_text_StyleConstants__24FontConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyleConstants__24FontConstants$sub_refs	_jc_javax_swing_text_StyleConstants__24FontConstants$sub_refs;
typedef struct _jc_javax_swing_text_StyleConstants__24FontConstants$sub_nonrefs	_jc_javax_swing_text_StyleConstants__24FontConstants$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyleConstants__24FontConstants$refs	_jc_javax_swing_text_StyleConstants__24FontConstants$refs;
typedef struct _jc_javax_swing_text_StyleConstants__24FontConstants$nonrefs	_jc_javax_swing_text_StyleConstants__24FontConstants$nonrefs;
typedef struct _jc_javax_swing_text_StyleConstants__24FontConstants$object	_jc_javax_swing_text_StyleConstants__24FontConstants$object;

typedef struct _jc_javax_swing_text_StyleConstants__24FontConstants$fields_struct	_jc_javax_swing_text_StyleConstants__24FontConstants$fields_struct;
typedef const struct _jc_javax_swing_text_StyleConstants__24FontConstants$vmethods	_jc_javax_swing_text_StyleConstants__24FontConstants$vmethods;
typedef const struct _jc_javax_swing_text_StyleConstants__24FontConstants$vtable	_jc_javax_swing_text_StyleConstants__24FontConstants$vtable;
typedef const struct _jc_javax_swing_text_StyleConstants__24FontConstants$vtype	_jc_javax_swing_text_StyleConstants__24FontConstants$vtype;

// Class fields structure
struct _jc_javax_swing_text_StyleConstants__24FontConstants$fields_struct {
	struct _jc_java_lang_Object$object	*Bold;
	struct _jc_java_lang_Object$object	*Family;
	struct _jc_java_lang_Object$object	*Italic;
	struct _jc_java_lang_Object$object	*Size;
};
extern _jc_javax_swing_text_StyleConstants__24FontConstants$fields_struct _jc_javax_swing_text_StyleConstants__24FontConstants$class_fields;

// Constructors
extern void _jc_javax_swing_text_StyleConstants__24FontConstants$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_text_StyleConstants__24FontConstants$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_javax_swing_text_StyleConstants__24FontConstants$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_text_StyleConstants__24FontConstants$vmethods {
};

// Vtable
struct _jc_javax_swing_text_StyleConstants__24FontConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_StyleConstants$vmethods	javax_swing_text_StyleConstants;
	_jc_javax_swing_text_StyleConstants__24FontConstants$vmethods	javax_swing_text_StyleConstants__24FontConstants;
};

// Vtype
struct _jc_javax_swing_text_StyleConstants__24FontConstants$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyleConstants__24FontConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyleConstants__24FontConstants$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyleConstants__24FontConstants$refs {
    _jc_javax_swing_text_StyleConstants__24FontConstants$sub_refs	javax_swing_text_StyleConstants__24FontConstants;
    _jc_javax_swing_text_StyleConstants$sub_refs	javax_swing_text_StyleConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyleConstants__24FontConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyleConstants__24FontConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_StyleConstants$sub_nonrefs	javax_swing_text_StyleConstants;
    _jc_javax_swing_text_StyleConstants__24FontConstants$sub_nonrefs	javax_swing_text_StyleConstants__24FontConstants;
};

// Object instance structure
struct _jc_javax_swing_text_StyleConstants__24FontConstants$object {
	_jc_javax_swing_text_StyleConstants__24FontConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyleConstants__24FontConstants$vtype	*vtype;
	_jc_javax_swing_text_StyleConstants__24FontConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyleConstants__24FontConstants$vtype _jc_javax_swing_text_StyleConstants__24FontConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyleConstants__24FontConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyleConstants__24FontConstants$class_object;

#endif	/* _JC_javax_swing_text_StyleConstants__24FontConstants_H_ */
